=======
Credits
=======

Development Lead
----------------

* Travis Logan <logan.travis@ouranos.ca> `@tlogan2000 <https://github.com/tlogan2000>`_

Co-Developers
-------------

* Sébastien Biner <biner.sebastien@ouranos.ca> `@sbiner <https://github.com/sbiner>`_
* Pascal Bourgault <bourgault.pascal@ouranos.ca> `@aulemahal <https://github.com/aulemahal>`_
* David Huard <huard.david@ouranos.ca> `@huard <https://github.com/huard>`_
* Gabriel Rondeau-Genesse <rondeau-genesse.gabriel@ouranos.ca> `@RondeauG <https://github.com/RondeauG>`_
* Philippe Roy <roy.philippe@ouranos.ca> `@Balinus <https://github.com/Balinus>`_
* Trevor James Smith <smith.trevorj@ouranos.ca> `@Zeitsperre <https://github.com/Zeitsperre>`_
* Juliette Lavoie <lavoie.juliette@ouranos.ca> `@juliettelavoie <https://github.com/juliettelavoie>`_

Contributors
------------

* David Caron `@davidcaron <https://github.com/davidcaron>`_
* Jwen Fai Low `@jwenfai <https://github.com/jwenfai>`_
* Marie-Pier Labonté `@marielabonte <https://github.com/marielabonte>`_
* Jeremy Fyke `@jeremyfyke <https://github.com/jeremyfyke>`_
* Clair Barnes <clair.barnes.16@ucl.ac.uk> `@clairbarnes <https://github.com/clairbarnes>`_
* Raquel Alegre <raquel.alegre@gmail.com> `@raquel-ucl <https://github.com/raquel-ucl>`_
* Abel Aoun <aoun.abel@gmail.com> `@bzah <https://github.com/bzah>`_
